@@ -20,6 +20,7 @@ from mitosheet.api.get_column_dtype import get_column_dtype
 from mitosheet.api.get_import_summary import get_import_summary
 from mitosheet.api.get_column_describe import get_column_describe
 from mitosheet.api.get_dateframe_as_csv import get_dataframe_as_csv
+from mitosheet.api.get_unique_value_counts import get_unique_value_counts
 from mitosheet.api.get_saved_analysis_description import get_saved_analysis_description
 
 
@@ -120,6 +121,8 @@ def handle_api_event(send, event, steps_manager):
         result = get_saved_analysis_description(event, steps_manager)
     elif event['type'] == 'get_pivot_params':
         result = get_pivot_params(event, steps_manager)
+    elif event['type'] == 'get_unique_value_counts':
+        result = get_unique_value_counts(event, steps_manager)
     else:
         raise Exception(f'Event: {event} is not a valid API call')
     
