@@ -65,8 +65,10 @@ def get_path_contents(event):
         filenames = []
     
     # We then filter out any hidden folders, which we don't want users to be able
-    # to see (as they would otherwise)
-    dirnames = [d for d in dirnames if not d.startswith('.')]
+    # to see (as they would otherwise). 
+    # Linux, Max == starts with "."
+    # Windows == "$"
+    dirnames = [d for d in dirnames if (not d.startswith('.') and not d.startswith('$'))]
 
     return json.dumps({
         'path': path,
