@@ -1,8 +1,9 @@
 #!/usr/bin/env python
 # coding: utf-8
 
-# Copyright (c) Saga Inc.
-# Distributed under the terms of the GPL License.
+# Copyright (c) Mito.
+# Distributed under the terms of the Modified BSD License.
+
 """
 Contains helpful utility functions for saving and reading
 in analyses.
@@ -11,11 +12,10 @@ in analyses.
 from mitosheet.step import Step
 import os
 import json
-from typing import Any, Dict, List, Optional
+from typing import List
+
 from mitosheet._version import __version__
-from mitosheet.telemetry.telemetry_utils import log
-from mitosheet.types import StepsManagerType
-from mitosheet.utils import NpEncoder
+from mitosheet.mito_analytics import log
 
 
 # Where all global .mito files are stored
@@ -26,23 +26,14 @@ MITO_FOLDER = os.path.expanduser("~/.mito")
 SAVED_ANALYSIS_FOLDER = os.path.join(MITO_FOLDER, 'saved_analyses')
 
 
-def get_analysis_exists(analysis_name: Optional[str]) -> bool:
-    """
-    Given an analysis_name, returns if the saved analysis in
-    ~/.mito/{analysis_name}.json exists
-    """
-
-    if analysis_name is None:
-        return False
-
-    analysis_path = f'{SAVED_ANALYSIS_FOLDER}/{analysis_name}.json'
-    return os.path.exists(analysis_path)
-
-def read_analysis(analysis_name: str) -> Optional[Dict[str, Any]]:
+def read_analysis(analysis_name):
     """
     Given an analysis_name, reads the saved analysis in
     ~/.mito/{analysis_name}.json and returns a JSON object
     representing it.
+
+    Also, checks if the analysis name is in the list of Mito
+    saves, and will return that if so.
     """
 
     analysis_path = f'{SAVED_ANALYSIS_FOLDER}/{analysis_name}.json'
@@ -57,7 +48,7 @@ def read_analysis(analysis_name: str) -> Optional[Dict[str, Any]]:
         except: 
             return None
 
-def read_and_upgrade_analysis(analysis_name: str) -> Optional[Dict[str, Any]]:
+def read_and_upgrade_analysis(analysis_name):
     """
     Given an analysis_name, reads the saved analysis in
     ~/.mito/{analysis_name}.json, does it's best to upgrade it to the current
@@ -97,7 +88,7 @@ def delete_saved_analysis(analysis_name):
 
     analysis = read_analysis(analysis_name)
 
-    # If the analysis name exists, delete it
+    # If the saved_analysis_name exists, delete it
     if analysis is not None:
         os.remove(os.path.join(SAVED_ANALYSIS_FOLDER, analysis_name + '.json'))
     else:
@@ -123,19 +114,45 @@ def rename_saved_analysis(old_analysis_name, new_analysis_name):
         raise Exception(f'Invalid rename, with old and new analysis are {old_analysis_name} and {new_analysis_name}')
 
 
-def write_saved_analysis(analysis_path: str, steps_data: List[Dict[str, Any]], version: str=__version__) -> None:
+def read_saved_analysis_names():
+    """
+    Reads the names of all the analyses saved by the user.
+
+    Does not return any of the auto-saved analyses!
+    """
+    if not os.path.exists(SAVED_ANALYSIS_FOLDER):
+        return []
+
+    file_names = [
+        f for f in os.listdir(SAVED_ANALYSIS_FOLDER) 
+        if os.path.isfile(os.path.join(SAVED_ANALYSIS_FOLDER, f))
+        and not f.startswith('UUID-')
+    ]
+
+    # We make sure they are in alphabetical order!
+    file_names.sort()
+
+    return [
+        file_name[:-5] for file_name in file_names 
+        if file_name.endswith('.json')
+    ]
+
+def saved_analysis_names_json():
+    return json.dumps(read_saved_analysis_names())
+
+def write_saved_analysis(analysis_path, steps_data, version=__version__):
     with open(analysis_path, 'w+') as f:
         saved_analysis = {
             'version': version,
             'steps_data': steps_data
         }
 
-        f.write(json.dumps(saved_analysis, cls=NpEncoder))
+        f.write(json.dumps(saved_analysis))
 
 
 def make_steps_json_obj(
         steps: List[Step]
-    ) -> List[Dict[str, Any]]:
+    ):
     """
     Given a steps dictonary from a steps_manager, puts the steps
     into a format that can be saved to a json file. 
@@ -184,7 +201,7 @@ def make_steps_json_obj(
 
     return steps_json_obj
 
-def write_analysis(steps_manager: StepsManagerType, analysis_name: str=None) -> None:
+def write_analysis(steps_manager, analysis_name=None):
     """
     Writes the analysis saved in steps_manager to
     ~/.mito/{analysis_name}. If analysis_name is none, gets the temporary
@@ -205,7 +222,7 @@ def write_analysis(steps_manager: StepsManagerType, analysis_name: str=None) ->
         analysis_name = steps_manager.analysis_name
 
     analysis_path = f'{SAVED_ANALYSIS_FOLDER}/{analysis_name}.json'
-    steps = make_steps_json_obj(steps_manager.steps_including_skipped)
+    steps = make_steps_json_obj(steps_manager.steps)
 
     # Actually write the file
     write_saved_analysis(analysis_path, steps)
