@@ -17,7 +17,7 @@ from mitosheet.sheet_functions.types.utils import (
     get_mito_type,
     get_nan_indexes_metadata, put_nan_indexes_back
 )
-from mitosheet.errors import EditError, make_execution_error, make_invalid_arguments_error
+from mitosheet.errors import MitoError, make_function_error, make_invalid_arguments_error
 from mitosheet.sheet_functions.types import SERIES_CONVERSION_FUNCTIONS
 
 
@@ -30,10 +30,10 @@ def handle_sheet_function_errors(sheet_function):
     def wrapped_f(*args):
         try:
             return sheet_function(*args)
-        except EditError as e:
+        except MitoError as e:
             raise e
         except:
-            raise make_execution_error()
+            raise make_function_error(sheet_function.__name__, error_modal=False)
     
     return wrapped_f
 
