@@ -5,14 +5,13 @@
 # Distributed under the terms of the Modified BSD License.
 
 from copy import deepcopy
-from mitosheet.sheet_functions.types.utils import NUMBER_SERIES
-from mitosheet.step_performers.step_performer import StepPerformer
-from mitosheet.state import State
 from typing import Any, Dict, List, Optional
-from mitosheet.errors import (
-    make_column_exists_error,
-    make_no_sheet_error
-)
+
+from mitosheet.errors import make_column_exists_error, make_no_sheet_error
+from mitosheet.sheet_functions.types.utils import NUMBER_SERIES
+from mitosheet.state import State
+from mitosheet.step_performers.step_performer import StepPerformer
+
 
 class AddColumnStepPerformer(StepPerformer):
     """""
@@ -54,7 +53,7 @@ class AddColumnStepPerformer(StepPerformer):
         if not prev_state.does_sheet_index_exist_within_state(sheet_index):
             raise make_no_sheet_error(sheet_index)
 
-        if column_header in prev_state.column_metatype[sheet_index]:
+        if column_header in prev_state.dfs[sheet_index].keys():
             raise make_column_exists_error(column_header)
 
         # We add a new step with the added column
@@ -65,12 +64,13 @@ class AddColumnStepPerformer(StepPerformer):
             column_header_index = len(prev_state.dfs[sheet_index].columns)
 
         # Update the state variables
-        post_state.column_metatype[sheet_index][column_header] = 'formula'
-        post_state.column_type[sheet_index][column_header] = NUMBER_SERIES
-        post_state.column_spreadsheet_code[sheet_index][column_header] = '=0'
-        post_state.column_python_code[sheet_index][column_header] = f'df[\'{column_header}\'] = 0'
-        post_state.column_evaluation_graph[sheet_index][column_header] = set()
-        post_state.column_filters[sheet_index][column_header] = {'operator': 'And', 'filters': []}
+        column_id = post_state.column_ids.add_column_header(sheet_index, column_header)
+        post_state.column_metatype[sheet_index][column_id] = 'formula'
+        post_state.column_type[sheet_index][column_id] = NUMBER_SERIES
+        post_state.column_spreadsheet_code[sheet_index][column_id] = '=0'
+        post_state.column_python_code[sheet_index][column_id] = f'df[\'{column_header}\'] = 0'
+        post_state.column_evaluation_graph[sheet_index][column_id] = set()
+        post_state.column_filters[sheet_index][column_id] = {'operator': 'And', 'filters': []}
             
         # Update the dataframe
         post_state.dfs[sheet_index].insert(column_header_index, column_header, 0)
@@ -89,7 +89,6 @@ class AddColumnStepPerformer(StepPerformer):
         column_header: str,
         column_header_index: int
     ) -> List[str]:
-
         return [
             f'{post_state.df_names[sheet_index]}.insert({execution_data["column_header_index"]}, \'{column_header}\', 0)'
         ]
@@ -106,4 +105,4 @@ class AddColumnStepPerformer(StepPerformer):
         if df_names is not None:
             df_name = df_names[sheet_index]
             return f'Added column {column_header} to {df_name}'
-        return f'Added column {column_header}' 
\ No newline at end of file
+        return f'Added column {column_header}' 
