@@ -203,16 +203,6 @@ class ChangeColumnDtypeStepPerformer(StepPerformer):
             post_state.dfs[sheet_index][column_header] = new_column
             post_state.column_type[sheet_index][column_id] = get_mito_type(new_column)
             
-            # We check if there are formula columns that rely on this type, and log if
-            # so, so that know if this is an issue folks run into
-            if len(post_state.column_evaluation_graph[sheet_index][column_id]) > 0:
-                log(
-                    'change_column_dtype_column_has_dependents',
-                    {
-                        'column_header': column_header
-                    }
-                )
-
             refresh_dependant_columns(post_state, post_state.dfs[sheet_index], sheet_index)
 
             return post_state, None
@@ -342,7 +332,7 @@ class ChangeColumnDtypeStepPerformer(StepPerformer):
                 pass
 
         code = [f'{df_name}[\'{column_header}\'] = {conversion_code}']
-        code = code + transpile_dependant_columns(post_state, sheet_index, column_header)
+        code = code + transpile_dependant_columns(post_state, sheet_index, column_id)
 
         return code
 
