@@ -53,6 +53,12 @@ class RenameColumnStepPerformer(StepPerformer):
         if new_column_header in prev_state.dfs[sheet_index].keys():
             raise make_column_exists_error(new_column_header)
 
+        # If the user has deleted the entire column header entirely, this is very likely
+        # a mistake and not something they meant to do... so we just don't make any edits
+        # and don't throw an error
+        if new_column_header == '':
+            return None
+
         # Create a new post state for this step
         post_state = deepcopy(prev_state)
 
@@ -75,6 +81,11 @@ class RenameColumnStepPerformer(StepPerformer):
         column_id: str,
         new_column_header: str
     ) -> List[str]:
+        
+        # Process the no-op if the header is empty
+        if new_column_header == '':
+            return []
+
         df_name = post_state.df_names[sheet_index]
         old_column_header = prev_state.column_ids.get_column_header_by_id(sheet_index, column_id)
         rename_dict = "{\"" + old_column_header + "\": \"" + new_column_header + "\"}"
