@@ -44,7 +44,7 @@ class MitoWidgetTestWrapper:
         Adds a column.
         """
 
-        self.mito_widget.receive_message(self.mito_widget, {
+        return self.mito_widget.receive_message(self.mito_widget, {
             'event': 'edit_event',
             'id': get_new_id(),
             'type': 'add_column_edit',
@@ -75,7 +75,7 @@ class MitoWidgetTestWrapper:
             column_header
         )
 
-        self.mito_widget.receive_message(
+        return self.mito_widget.receive_message(
             self.mito_widget,
             {
                 'event': 'edit_event',
@@ -118,7 +118,7 @@ class MitoWidgetTestWrapper:
             for column_header in selected_columns_two
         ]
 
-        self.mito_widget.receive_message(
+        return self.mito_widget.receive_message(
             self.mito_widget,
             {
                 'event': 'edit_event',
@@ -160,7 +160,7 @@ class MitoWidgetTestWrapper:
             for column_header, value in values.items()
         }
 
-        self.mito_widget.receive_message(
+        return self.mito_widget.receive_message(
             self.mito_widget,
             {
                 'event': 'edit_event',
@@ -192,7 +192,7 @@ class MitoWidgetTestWrapper:
             column_header
         )
 
-        self.mito_widget.receive_message(
+        return self.mito_widget.receive_message(
             self.mito_widget,
             {
                 'event': 'edit_event',
@@ -226,7 +226,7 @@ class MitoWidgetTestWrapper:
         )
 
 
-        self.mito_widget.receive_message(
+        return self.mito_widget.receive_message(
             self.mito_widget,
             {
                 'event': 'edit_event',
@@ -254,7 +254,7 @@ class MitoWidgetTestWrapper:
             column_header
         )
 
-        self.mito_widget.receive_message(
+        return self.mito_widget.receive_message(
             self.mito_widget,
             {
                 'event': 'edit_event',
@@ -281,7 +281,7 @@ class MitoWidgetTestWrapper:
             column_header
         )
 
-        self.mito_widget.receive_message(
+        return self.mito_widget.receive_message(
             self.mito_widget,
             {
                 'event': 'edit_event',
@@ -303,7 +303,7 @@ class MitoWidgetTestWrapper:
             old_column_header
         )
 
-        self.mito_widget.receive_message(
+        return self.mito_widget.receive_message(
             self.mito_widget,
             {
                 'event': 'edit_event',
@@ -324,7 +324,7 @@ class MitoWidgetTestWrapper:
             column_header
         )
 
-        self.mito_widget.receive_message(
+        return self.mito_widget.receive_message(
             self.mito_widget,
             {
                 'event': 'edit_event',
@@ -345,7 +345,7 @@ class MitoWidgetTestWrapper:
             column_header
         )
 
-        self.mito_widget.receive_message(
+        return self.mito_widget.receive_message(
             self.mito_widget,
             {
                 'event': 'edit_event',
@@ -361,7 +361,7 @@ class MitoWidgetTestWrapper:
         )
 
     def simple_import(self, file_names: List[str]):
-        self.mito_widget.receive_message(
+        return self.mito_widget.receive_message(
             self.mito_widget,
             {
                 'event': 'edit_event',
@@ -375,7 +375,7 @@ class MitoWidgetTestWrapper:
         )
 
     def bulk_old_rename(self, move_to_deprecated_id_algorithm=False):
-        self.mito_widget.receive_message(
+        return self.mito_widget.receive_message(
             self.mito_widget,
             {
                 'event': 'edit_event',
@@ -390,7 +390,7 @@ class MitoWidgetTestWrapper:
 
     
     def undo(self):
-        self.mito_widget.receive_message(
+        return self.mito_widget.receive_message(
             self.mito_widget,
             {
                 'event': 'update_event',
@@ -400,7 +400,7 @@ class MitoWidgetTestWrapper:
         )
     
     def redo(self):
-        self.mito_widget.receive_message(
+        return self.mito_widget.receive_message(
             self.mito_widget,
             {
                 'event': 'update_event',
@@ -410,7 +410,7 @@ class MitoWidgetTestWrapper:
         )
 
     def clear(self):
-        self.mito_widget.receive_message(
+        return self.mito_widget.receive_message(
             self.mito_widget,
             {
                 'event': 'update_event',
@@ -420,7 +420,7 @@ class MitoWidgetTestWrapper:
         )
     
     def save_analysis(self, analysis_name):
-        self.mito_widget.receive_message(
+        return self.mito_widget.receive_message(
             self.mito_widget,
             {
                 'event': 'update_event',
@@ -432,7 +432,7 @@ class MitoWidgetTestWrapper:
 
 
     def rename_analysis(self, old_analysis_name, new_analysis_name):
-        self.mito_widget.receive_message(
+        return self.mito_widget.receive_message(
             self.mito_widget,
             {
                 'event': 'update_event',
@@ -445,7 +445,7 @@ class MitoWidgetTestWrapper:
 
     
     def delete_analysis(self, analysis_name):
-        self.mito_widget.receive_message(
+        return self.mito_widget.receive_message(
             self.mito_widget,
             {
                 'event': 'update_event',
@@ -456,7 +456,7 @@ class MitoWidgetTestWrapper:
         )
 
     def delete_dataframe(self, sheet_index):
-        self.mito_widget.receive_message(
+        return self.mito_widget.receive_message(
             self.mito_widget,
             {
                 'event': 'edit_event',
@@ -470,7 +470,7 @@ class MitoWidgetTestWrapper:
         )
 
     def duplicate_dataframe(self, sheet_index):
-        self.mito_widget.receive_message(
+        return self.mito_widget.receive_message(
             self.mito_widget,
             {
                 'event': 'edit_event',
@@ -484,7 +484,7 @@ class MitoWidgetTestWrapper:
         )
 
     def rename_dataframe(self, sheet_index, new_dataframe_name):
-        self.mito_widget.receive_message(
+        return self.mito_widget.receive_message(
             self.mito_widget,
             {
                 'event': 'edit_event',
@@ -504,7 +504,7 @@ class MitoWidgetTestWrapper:
             column_header
         )
 
-        self.mito_widget.receive_message(
+        return self.mito_widget.receive_message(
             self.mito_widget,
             {
                 'event': 'edit_event',
@@ -521,7 +521,7 @@ class MitoWidgetTestWrapper:
         )
 
     def replay_analysis(self, analysis_name, import_summaries=None, clear_existing_analysis=False):
-        self.mito_widget.receive_message(
+        return self.mito_widget.receive_message(
             self.mito_widget,
             {
                 'event': 'update_event',
@@ -534,7 +534,7 @@ class MitoWidgetTestWrapper:
         )
 
     def checkout_step_by_idx(self, index):
-        self.mito_widget.receive_message(
+        return self.mito_widget.receive_message(
             self.mito_widget,
             {
                 'event': 'update_event',
