@@ -39,7 +39,7 @@ def execute_replay_analysis_update(
         steps_manager.steps = steps_manager.steps[:1]
 
     # If we're getting an event telling us to update, we read in the steps from the file
-    analysis = read_and_upgrade_analysis(analysis_name)
+    analysis = read_and_upgrade_analysis(analysis_name)    
 
     # When replaying an analysis with import events, you can also send over
     # new params to the import events to replace them. We replace them in the steps here
@@ -51,8 +51,22 @@ def execute_replay_analysis_update(
 
     # We stupidly store our saved steps here as a mapping, so we go through and turn it into 
     # a list so that we can pass it into other functions
-    steps_manager.execute_steps_data(new_steps_data=analysis['steps_data'])
+    # If the analysis is getting replayed because of replaying a saved analysis through the Mitosheet UI, 
+    # then we filter out the set_cell_value steps 
+    if not clear_existing_analysis:
+        steps_excluding_set_cell_value_steps = filter(skip_set_cell_value_steps, analysis['steps_data'])
+    else: 
+        steps_excluding_set_cell_value_steps = analysis['steps_data']
+    steps_manager.execute_steps_data(new_steps_data=steps_excluding_set_cell_value_steps)
 
+def skip_set_cell_value_steps(step_data):
+    """
+    Helper function for filtering out set_cell_value steps. We do this when
+    the analysis is getting replayed because of replaying a saved analysis.
+    """
+    if step_data['step_type'] == 'set_cell_value':
+        return False
+    return True
 
 REPLAY_ANALYSIS_UPDATE = {
     'event_type': REPLAY_ANALYSIS_UPDATE_EVENT,
